# MIH's extra DataLad functionality

[![Build status](https://ci.appveyor.com/api/projects/status/f65qpwkv2rueii1d/branch/master?svg=true)](https://ci.appveyor.com/project/mih/datalad-mihextras/branch/master) [![codecov.io](https://codecov.io/github/datalad/mih/datalad-mihextras/coverage.svg?branch=master)](https://codecov.io/github/datalad/mih/datalad-mihextras?branch=master) [![docs](https://github.com/mih/datalad-mihextras/workflows/docs/badge.svg)](https://datalad-mihextras.readthedocs.io)

DataLad extension with special interest functionality or drafts of future
additions to DataLad proper.

This is a staging area to test-drive new functionality in the wild without
making any promises on longevity or stability. Once a certain level of maturity
has been reached, most functionality will move to more appropriate places, like
topical extensions or even DataLad proper.
